Defines a class that holds modelmoments for a finite mixture of Binomial
distributions. Note that this class is not directly used, but indirectly
when calling the modelmoments constructor modelmoments().
This is a class that directly inherits from the dmodelmoments class.
modelmoments for the base class for model moments
modelmoments() for the constructor of modelmoments classes
dmodelmoments class for the parent class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.