Stores moments of an fdata object containing continuous data.
The fdata object is stored in the parent datamoments
class.
higherAn array containing the four higher centralized moments of the
continuous data stored in the fdata object.
skewnessA vector storing the skewness of the continuous data in the
corresponding fdata object.
kurtosisA vector storing the kurtosis of the continuous data in the
corresponding fdata object.
corrA matrix containing the correlations between the data dimensions
in case of multivariate data (i.e. slot r in the fdata object is
larger than one).
smomentsA csdatamoments object, if the fdata object also holds
indicators. NULL, if no indicators are present in the fdata object.
datamoments for the parent class
ddatamoments for the corresponding class for discrete data
csdatamoments for the contained class if indicators
are present in the fdata object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.