This class defines the general theoretical moments of a finite mixture model with continuous data.
higherAn array containing the four higher centralized moments of the (in case of multivariate data marginal) finite mixture.
skewnessA vector containing the skewness(es) of the finite mixture model.
kurtosisA vector containing the kurtosis(es) of the finite mixture model.
modelmoments for the base class
modelmoments() for the constructor of any modelmoments inherited class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.