Description Usage Arguments Value References See Also
Calling dataclass() classifies data using a fully specified mixture model.
Henceforth, the finite mixture model model must be fully specified, i.e.
containing parameters in slot par, weights in slot weight and
indicators in slot S of the corresponding fdata object.
1 |
fdata |
An |
model |
A |
simS |
A logical defining, if the indicators |
A dataclass object containing the classification matrix,
model log-likelihood, entropy and indicators, if the latter have been
simulated.
Frühwirth-Schnatter, S. (2006), "Finite Mixture and Markov Switching Models"
dataclass for the class definition
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.