Description Slots References See Also
Stores objects to classify observations using a fully specified mixture model. If the indicators are known a finite mixture model is fully specified as then the likelihood can be calculated for each observation depending on the component it stems from.
logpyAn array containing the logarithmized
probAn array storing the probability classification matrix that
defines for each observation the probability of belonging to component
k. Henceforth, each row sums to one. The dimension of this array is
N x K.
mixlikA numeric storing the logarithm of the mixture likelihood
evaluated at certain parameters par from a finmix model object and
corresponding weights.
entropyA numeric storing the entropy of the classification.
loglikcdAn array storing the logarithm of the conditional likelihood
of each component parameter, if indicators have not been simulated. The
array has dimension 1 x K.
postSA numeric storing the posterior probability of the indicators
S in the data, if indicators have been simulated.
Frühwirth-Schnatter, S. (2006), "Finite Mixture and Markov Switching Models"
fdata for the class holding the data
model for the class defining a finite mixture model
dataclass() for the constructor of this class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.