Stores moments of an fdata object containing discrete data.
The fdata object is stored in the parent datamoments
class.
factorialAn array containing the first four factorial moments of the
discrete data stored in the fdata object.
overA vector storing the overdispersion of the discrete data in the
corresponding fdata object.
zeroA vector storing the fractions of zeros in the observed data. <
smomentsAn sdatamoments object, if the fdata object also holds
indicators. NULL, if no indicators are present in the fdata object.
datamoments for the parent class
ddatamoments for the corresponding class for continuous data
sdatamoments for the contained class if indicators
are present in the fdata object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.