Description Usage Arguments Value See Also Examples
hasExp() checks, if the object contains exp data.
1 2 |
object |
An |
verbose |
A logical indicating, if the function should print out messages. |
Either FALSE/TRUE, if verbose is FALSE and the exp slot is
empty or filled or a message, if verbose is TRUE.
fdata for the class definition
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.