This class defines hyper-parameters for the MCMC procedure. This is a main
class of the finmix package that must be defined for estimating a finite
mixture model.
burninAn integer defining the number of steps in the burn-in phase of Gibbs-sampling.
MAn integer defining the number of steps in Gibbs-sampling to be stored.
startparA logical indicating, if starting by sampling the
parameters. If FALSE sampling starts by sampling the indicators S.
storeSAn integer specifying how many of the last sampled indicators should be stored in the output.
storepostA logical indicating if the posterior probabilities should be stored. This becomes for example important for specific relabeling algorithms, but also for analysis.
ranpermA logical indicating, if random permutation should be used. If
TRUE the parameters are permutated randomly between the number of
components after each sampling step in MCMC.
storeinvA logical indicating if the inverse variance-covariance matrices for multivariate normal or Student-t mixtures should be stored.
mcmc() for the class constructor
mcmcstart() for completion of slots
mixturemcmc() for further information about the MCMC sampling
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.