This class stores the point estimators for component parameters and weights as well as corresponding information from MCMC sampling. Three point estimators are calculated: the maximum a posterior (MAP), the Bayesian maximum likelihood (BML) and the Identified ergodic average (IEAVG). See Fr\"uhwirth-Schnatter (2006) for detailed information about how these estimators are defined.
distA character specifying the distribution family of the mixture model used in MCMC sampling.
KAn integer specifying the number of components in the mixture model.
indicmodA character specifying the indicator model. At this moment only a multinomial model can be chosen.
burninAn integer specifying the number of iterations in the burn-in phase of MCMC sampling.
MAn integer specifying the number of iterations to store in MCMC sampling.
ranpermA logical specifying, if random permutation has been used during MCMC sampling.
relabelA character specifying the re-labeling algorithm used during parameter estimation for the identified ergodic average.
mapA named list containing the parameter estimates of the MAP. The
element par is a named list and contains the component parameters and
the element weight contains the weights.
bmlA named list containing the parameter estimates of the BML. The
element par is a named list and contains the component parameters and
the element weight contains the weights.
ieavgA named list containing the parameter estimates of the IEAVG. The
element par is a named list and contains the component parameters and
the element weight contains the weights.
sdpostA named list containing the standard deviations of the parameter estimates from the posterior distributions.
mcmcestind for the equivalent class for models with unknown indicators
mcmcestimate() to calculate point estimates
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.