mcmcestimate: Calculate point estimators from MCMC samples

Description Usage Arguments Value See Also

Description

Calling mcmcestimate() calculates the following point estimates from the MCMC samples:

For a more detailed outlay of point estimators from Bayesian mixture model estimation, see Fr\"uhwirth-Schnatter (2006).

Usage

1
2
3
4
5
6
7
mcmcestimate(
  mcmcout,
  method = "kmeans",
  fdata = NULL,
  permOut = FALSE,
  opt_ctrl = list(max_iter = 200L)
)

Arguments

mcmcout

An mcmcoutput object containing the sampled parameters and informaiton about the finite mixture model.

method

A character defining the re-labeling method in case of a model with unknown indicators. For most distributions there exists only a single choice, namely "kmeans". For Poisson and Binomial distributions the re-labeling algorithms "Stephens1997a" and "Stephens1997b" can be chosen.

fdata

An fdata model containing the observations. Optional.

permOut

A logical indicating, if the permuted MCMC samples should be returned as well. Optional.

opt_ctrl

A list with an element max_iter controlling the number of iterations in case the "Stephens1997a" re-labeling algorithm is chosen.

Value

An mcmcest object containing the point estimates together with additional information about the underlying finite mixture model, MCMC sampling hyper-parameters and the data. In case permOut is set to TRUE, the output of this function is a named list with an mcmcest object containing parameter estimates and in addition an mcmcoutputperm object containing the permuted (re-labeled) MCMC samples.

See Also


simonsays1980/finmix documentation built on Dec. 23, 2021, 2:25 a.m.