This is a leight-weighted class containing the major results from MCMC sampling to calculate model moments from MCMC samples. Note that momentarily only methods for the multivariate Normal mixture are implemented.
distA character defining the finite mixture model that has been used in MCMC sampling.
KAn integer specifying the number of components of the mixture model.
rAn integer specifying the number of dimensions of the mixture model.
parA list storing the sample component parameters from MCMC sampling.
weightA n array storing the sample weight parameters from MCMC sampling.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.