This class defines the basic slots for the MCMC sampling output when indicators are not known. It inherits from the mcmcoutputfix.
weightAn array of dimension M x K containing the sampled
weights.
entropyAn array of dimension M x 1 containing the entropy
for each MCMC draw.
STAn array of dimension M x 1 containing all MCMC states,
for the last observation in slot y of the fdata object passed in to
mixturemcmc() where a state is defined for non-Markov models as the
last indicator of this observation.
SAn array of dimension N x storeS containing the last
storeS indicators sampled. storeS is defined in the slot storeS of
the mcmc object passed into mixturemcmc().
NKAn array of dimension M x K containing the number of
observations assigned to each component for each MCMC draw.
clustAn array of dimension N x 1 containing the recent
indicators defining the last "clustering" of observations into the
mixture components.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.