This class defines the basic slots for the MCMC sampling output for a fixed indicator model.
MAn integer defining the number of iterations in MCMC sampling.
burninAn integer defining the number of iterations in the burn-in phase of MCMC sampling. These number of sampling steps are not stored in the output.
ranpermA logical indicating, if MCMC sampling has been performed with random permutations of components.
parA named list containing the sampled component parameters.
logA named list containing the values of the mixture log-likelihood, mixture prior log-likelihood, and the complete data posterior log-likelihood.
modelThe model object that specifies the finite mixture model for
whcih MCMC sampling has been performed.
priorThe prior object defining the prior distributions for the
component parameters that has been used in MCMC sampling.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.