This class stores in addition to the information from its parent class
mcmcoutputfix also the sampled parameters from the hierarchical prior.
hyperA list storing the sampled parameters from the hierarchical prior.
mcmcoutputfix for the parent class“
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.