This class stores samples from bayesian estimation with hierarchical prior
and unknown indicators. It inherits from mcmcoutputhier and adds to it a
slot to store the parameters from the posterior density. For a model with
unknown indicators the slot @indicfix in the model object specifying
the finite mixture model must be set to FALSE (default). Sampling with a
hierarchical prior is activated by setting the slot @hier in the prior
object to TRUE (default). Finally, to store parameters for the posterior
density the hyper-parameter storepost in the mcmc object must be set to
TRUE (default).
postA named list containing a named list par that contains arrays
storing the sampled posterior density parameters.
mcmcoutputhier for the parent class
prior for the class specifying the prior distribution
prior() for the prior class constructor
priordefine() for the advanced prior class constructor
mcmc for the class defining the hyper-parameters
mcmc() for the mcmc class constructor
model for the model class definition
model() for the model class constructor
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.