This class inherits from the mcmcoutputbase class and adds posterior
density parameters to the MCMC sampling output. The storage of posterior
parameters is controlled by the slot storepost in the mcmc
class. If set to TRUE posterior parameters are stored in the output of the
MCMC sampling.
postA named list containing a named list par with arrays for the
posterior density parameters.
mcmcoutputbase for the parent class
mixturemcmc() for performing MCMC sampling for finite mixture modeling
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.