This class defines objects to store the outputs from permuting the MCMC samples. Due to label switching the sampled component parameters are usually not assigned to the same component in each iteration. To overcome this issue the samples are permuted by using a relabeling algorithm (usually K-means) to reassign parameters. Note that due to assignment of parameters from the same iteration to the same component, the sample size could shrink.
This class stores the permuted parameters together with the new MCMC sample
size and the mixture log-likelihood, the prior log-likelihood, and the
complete data posterior log-likelihood. All this slots are inherited from
the parent class mcmcpermfix. In addition to these slots this class adds
permuted weights, permuted indicators as well as the entropies and number
of assigned observations per component.
relabelA character defining the used algorithm for relabeling.
weightpermAn array of dimension Mperm x K containing the
relabeled weight parameters.
entropypermAn array of dimension Mperm x 1 containing the
entropy for each MCMC permuted draw.
STpermAn array of dimension Mperm x 1 containing all permuted
MCMC states, for the last observation in slot @y of the fdata object
passed in to mixturemcmc() where a state is defined for non-Markov
models as the last indicator of this observation.
SpermAn array of dimension N x storeS containing the last
storeS permuted indicators. storeS is defined in the slot @storeS
of the mcmc object passed into mixturemcmc().
NKpermAn array of dimension Mperm x K containing the numbers
of observations assigned to each component.
mcmcpermute() for the calling function
mcmcpermfix for the corresponding class for models with fixed indicators
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.