Description Usage Arguments Value See Also Examples
Calling mcmcstart() creates starting values for MCMC sampling. Starting
values are constructed for the indicators in the fdata argument and the
parameters in the model argument. In addition an mcmc object can be
provided in the varargin argument to set up all slots consistently for a
non-default setting of hyper-parameters.
To assing the returned objects directly to existing names the assignment
operator %%=%% can be used together with a formula concatenating each name
with a tilde ~. See the examples.
1 |
fdata |
An |
model |
A |
varargin |
Either |
A list containing the fdata object, the model object and an
mcmc object all set up for MCMC sampling.
fdata for the definition of the fdata class
model for the definition of the model class
mcmc for the definition of the mcmc class
mixturemcmc() for the starting MCMC sampling
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.