Description Details Slots See Also
This class specifies a finite mixture model. Entities are created from it by
calling its constructor model().
A finite mixture model in the finmix package is defined by its number of
components K, the component distributions dist, the data dimension r
and an indicator defining, if the model has fixed or unknown indicators.
Finite mixture models for the following distributions can be constructed:
Poisson,
Conditional Poisson,
Exponential,
Binomial,
Normal,
Multivariate Normal,
Student-t,
Multivariate Student-t.
Using the constructor model() a finite mixture model can be created, the
default being a mixture model of Poisson distributions.
A fully defined finite mixture model contains next to the distribution and
the components also weights and parameters. The weights are defined in slot
weight and must be of class matrix with as many weights as there are
components in the mixture model (dimension Kx1). Parameters are defined in
a list named par. The elements of this list depend on the chosen
distribution in slot dist:
Poisson: A matrix named lambda of dimension Kx1 holding the rate
parameters.
Exponential: A matrix named lambda of dimension Kx1 holding the rate
parameters.
Binomial: A matrix of dimension Kx1 named p storing the
probabilities.
distA character, defining the distribution family. Possible choices are binomial, exponential, normal, normult, poisson, student, and studmult.
rAn integer. Defines the vector dimension of a model. Is one for all univariate distributions and larger than one for normult and studmult.
KAn integer, defining the number of components in the finite mixture.
weightA matrix, containing the weights of the finite mixture model.
The matrix must have dimension 1 x K and weights must add to one
must all be larger or equal to zero.
parA list containing the parameter vectors for the finite mixture distribution. The list can contain more than one named parameter vector.
indicmodA character defining the indicator model. So far only multinomial indicator models are possible.
indicfixA logical. If TRUE the indicators are given and
therefore fixed.
TA matrix containing the repetitions in case of a "binomial" or
"poisson" model.
mixturemcmc() for performing MCMC sampling with a mixture model
modelmoments() for compute theoretical moments of a finite mixture model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.