Description Usage Arguments Value See Also Examples
Calling modelmoments() calculates the corresponding moments of the
finite mixture distribution defined in the model object. The model
object should contain parameters in slot par and weights in slot weight.
1 |
model |
A |
A modelmoments object with calculated moments of the finite
mixture model defined in the model object.
modelmoments for all slots of the modelmoments class
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.