Defines a container to hold the moments of a finite mixture model. The
finmix model object should contains parameters and weights.
meanA vector of component means.
varAn array of components variances or in case of multivariate distributions covariance matrices.
modelThe corresponding model object.
modelmoments() for the constructor of the modelmoments class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.