permmoments_cc: Calculate moments on permuted samples of multivariate mixture...

Description Usage Arguments Value See Also

View source: R/RcppExports.R

Description

This function calculates the moments for re-labeled MCMC samples of multivariate mixture models. Moments like means, standard deviations, kurtosis and skewness are computed for each iteration in MCMC sampling. The moments are used when plotting the traces of an MCMC sample output.

Usage

1
permmoments_cc(classS4)

Arguments

classS4

An mcmcoutputperm class containing the re-labeled MCMC samples.

Value

A named list with vectors containing the data moments for each iteration in the re-labeled MCMC sample.

See Also


simonsays1980/finmix documentation built on Dec. 23, 2021, 2:25 a.m.