plot-fdata-missing-method: Plots the data

Description Usage Arguments See Also Examples

Description

plot() plots the data in an fdata object by either a histogram in case of continuous data or a barplot in case of discrete data.

Usage

1
2
## S4 method for signature 'fdata,missing'
plot(x, y, dev = TRUE, ...)

Arguments

x

An fdata object. Cannot be empty.

y

Unused.

dev

A logical indicating if the plot should be output via a graphical device.

...

Further arguments passed to the plotting functions hist or barplot.

See Also

fdata class

Examples

1
2
3
# Generate Poisson data and plot it. 
f_data <- fdata(y = rpois(100, 312), sim = TRUE)
plot(f_data)

simonsays1980/finmix documentation built on Dec. 23, 2021, 2:25 a.m.