plotPointProc-model-method: Plots the point process of a finite model

Description Usage Arguments Value See Also Examples

Description

plotPointProc plots the point process of an S4 model object that defines a finite mixture model. Only available for Poisson mixtures so far.

Usage

1
2
## S4 method for signature 'model'
plotPointProc(x, dev = TRUE, ...)

Arguments

x

An S4 model object with defined parameters and weights.

dev

A logical indicating, if the plot should be shown in a graphical device. Set to FALSE, if plotted to a file.

...

Arguments to be passed to methods, such as graphical parameters (see par).

Value

A scatter plot of weighted parameters.

See Also

model

Examples

1
2
3
4
## Not run: 
plotPointProc(f_model)

## End(Not run)

simonsays1980/finmix documentation built on Dec. 23, 2021, 2:25 a.m.