Description Slots References See Also
The prior class stores the specifications for the prior distribution used
for Bayesian estimation of the finite mixture parameters and weights. There
exists next to the general constructor also an advanced constructor that
specifies a data dependent prior. See priordefine() for this advanced
constructor.
weightA matrix storing the prior parameters for the weight of a
finite mixture model.
parA list storing the prior parameters for the parameters of a finite mixture model.
typeA character specifying what type of prior should be used in
Bayesian estimation. Either "independent" for an independent prior
distribution or "condconjugate" for a conditionally conjugate prior
distribution.
hierA logical defining, if the used prior should be hierarchical. Hierarchical prior are often more robust, but need an additional layer in sampling, so computing costs increase.
Frühwirth-Schnatter, S (2006), "Finite Mixture and Markov Switching Models"
prior() for the general constructor of this class
priordefine() for the advanced constructor of this class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.