Description Usage Arguments Value See Also Examples
Calling qinmatrmult() on multiple vectors of dimension r(r+1)/2x1
converts these vectors into an array of symmetric matrices of dimension
rxr. This function is used to handle the MCMC sampling output from
multivariate finite mixture models. To save storage the symmetric
variance-covariance matrices of multivariate mixtures are stored vector
form. If the covariance matrices are needed for calculations this function
helps to restore these matrices from the storage vectors.
1 | qinmatrmult(m)
|
m |
A matrix or array of vectors of dimension |
An array of symmetric matrices, all of dimension rxr.
qinmatr() for converting a single vector into a symmetric matrix
qincol() for converting a symmetric matrix into a vector
qincolmult() for converting an array of symmetric matrices into vectors
1 2 | # Convert a matrix of vectors
qinmatrmult(matrix(rnorm(36), nrow = 6))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.