Description Usage Arguments Value See Also Examples
Calling sdatamoments() constructs an object of class sdatamoments or
csdatamoments depending on the type slot of the argument value. If
this slot is "discrete" an sdatamoments object is returned and if the
slot is "continuous", a csdatamoments object is returned.
1 | sdatamoments(value = fdata())
|
value |
An fdata object containing the indicators for which moments should be calculated. |
If slot type of the argument value is "discrete" an
sdatamoments object is returned and if the slot is "continuous",
a csdatamoments object is returned.
sdatamoments for the class of indicator moments for discrete data
csdatamoments for the class of indicator moments for continuous
groupmoments for the parent class## Copyright (C) 2013 Lars Simon Zehnder
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.