Description Usage Arguments Value See Also Examples
Sets a value for the indicfix slot.
1 2 | ## S4 replacement method for signature 'model'
setIndicfix(object) <- value
|
object |
An |
value |
A logical specifying, if the model is one with fixed indicators. |
The model object with slot indicfix set to value.
model for the class definition
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.