setR-set-fdata-method: Setter method of 'fdata' class

Description Usage Arguments Value See Also Examples

Description

Sets the slot R of an fdata object and validates the slot data before setting.

Usage

1
2
## S4 replacement method for signature 'fdata'
setR(object) <- value

Arguments

object

An fdata objects, whose slot R should be set.

value

An integer that should be set as R slot of the fdata object.

Value

The fdata object with slot R set to value or an error message if the value cannot be set as slot R.

See Also

fdata for all slots of the fdata class

Examples

1
2
f_data <- fdata()
setR(f_data) <- as.integer(2)

simonsays1980/finmix documentation built on Dec. 23, 2021, 2:25 a.m.