setS-set-fdata-method: Setter method of 'fdata' class

Description Usage Arguments Value See Also Examples

Description

Sets the slot S of an fdata object and validates the slot data before setting.

Usage

1
2
## S4 replacement method for signature 'fdata'
setS(object) <- value

Arguments

object

An fdata object, whose slot S should be set.

value

A matrix that should be set as S slot of the fdata object. Has to be of type integer.

Value

The fdata object with slot S set to value or an error message if the value cannot be set as slot S.

See Also

fdata for all slots of the fdata class

Examples

1
2
3
# Generate an empty fdata object.
f_data <- fdata()
setS(f_data) <- matrix(sample.int(4, 100, replace = TRUE))

simonsays1980/finmix documentation built on Dec. 23, 2021, 2:25 a.m.