Description Usage Arguments Value See Also Examples
Sets the slot T of an fdata object and validates the slot data before
setting.
1 2 | ## S4 replacement method for signature 'fdata'
setT(object) <- value
|
object |
An |
value |
A matrix that should be set as |
The fdata object with slot T set to value or an error message
if the value cannot be set as slot T.
fdata for all slots of the fdata class
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.