Description Usage Arguments Value See Also Examples
Sets the slot y of an fdata object and validates the slot data before
setting.
1 2 | ## S4 replacement method for signature 'fdata'
setY(object) <- value
|
object |
An |
value |
A matrix that should be set as |
The fdata object with slot y set to value or an error message
if the value cannot be set as slot y.
fdata for all slots of the fdata class
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.