show-exponentialmodelmoments-method: Shows a summary of an 'exponentialmodelmoments' object.

Description Usage Arguments Value See Also

Description

Calling show() on an exponentialmodelmoments object gives an overview of the moments of an exponential finite mixture.

Usage

1
2
## S4 method for signature 'exponentialmodelmoments'
show(object)

Arguments

object

An exponentialmodelmoments object.

Value

A console output listing the slots and summary information about each of them.

See Also


simonsays1980/finmix documentation built on Dec. 23, 2021, 2:25 a.m.