Description Usage Arguments Value
Calling show() on a groupmoments object gives an overview
of the moments of a finit mixture with continuous data.
1 2 | ## S4 method for signature 'groupmoments'
show(object)
|
object |
A |
A console output listing the slots and summary information about each of them.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.