Defines a class that holds modelmoments for a finite mixture of studmult
distributions. Note that this class is not directly used, but indirectly
when calling the modelmoments constructor modelmoments().
BA numeric defining the between-group heterogeneity.
WA numeric defining the within-group heterogeneity.
RdetA numeric defining the coefficient of determination based on the determinant of the covariance matrix.
RtrA numeric defining the coefficient of determination based on the trace of the covariance matrix.
corrA matrix storing the correlation matrix.
modelmoments for the base class for model moments
modelmoments() for the constructor of modelmoments classes
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.