subseq-mcmcoutputfixhierpost-array-method: Constructs a sub-chain of MCMC samples

Description Usage Arguments Value

Description

Calling subseq() constructs an MCMC sub-chain from the samples in the passed-in mcmcoutput object specfied by the index array in index. This can be advantageous, if chains are non-stationary. For successful MCMC sampling the chain must be converged to the target distribution, the true distribution of parameters, weights and indicators.

Note that this method calls the equivalent method from the parent class and adds the sub-chains for the posterior density parameters.

Usage

1
2
## S4 method for signature 'mcmcoutputfixhierpost,array'
subseq(object, index)

Arguments

object

An mcmcoutput object containing all sampled values.

index

An array specifying the extraction of the sub-chain.

Value

An mcmcoutput object containing the values from the sub-chain.


simonsays1980/finmix documentation built on Dec. 23, 2021, 2:25 a.m.