Description Usage Arguments Value
Calling subseq() constructs an MCMC sub-chain from the samples in the
passed-in mcmcoutput object specfied by the index array in index. This
can be advantageous, if chains are non-stationary. For successful MCMC
sampling the chain must be converged to the target distribution, the true
distribution of parameters, weights and indicators.
Note that this method calls the equivalent method from the parent class and adds the sub-chains for the posterior density parameters.
1 2 | ## S4 method for signature 'mcmcoutputfixpost,array'
subseq(object, index)
|
object |
An |
index |
An array specifying the extraction of the sub-chain. |
An mcmcoutput object containing the values from the sub-chain.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.