swapST_cc: Swap the 'ST' slot in the MCMC output

Description Usage Arguments Value See Also

View source: R/RcppExports.R

Description

This function is used to swap the elements in slot ST of an mcmcoutput object (An MCMC sampling output). The main difference to the swapInteger_cc() function is that this function reuses memory from R. Do only use this function, if you really know what you are doing.

Usage

1
swapST_cc(values, index)

Arguments

values

An integer matrix containing the values to swap in R memory.

index

An integer matrix containing the swapping scheme.

Value

An integer matrix with swapped values.

See Also


simonsays1980/finmix documentation built on Dec. 23, 2021, 2:25 a.m.