Description Usage Arguments Value See Also
Calling mcmcestimate() calculates the following point estimates from the
MCMC samples:
MAP: The maximum a posterior estimates are defined as the mode of the (joint) posterior density.
BML: The Bayesian maximum likelihood estimator is based on the mixture log-likelihood function and defines the mode of this function.
EAVG: The ergodic average is calculated as an average over the MCMC traces of component parameters and weights (in case of unknown parameters).
IEAVG: The identified ergodic average is defined similar to the EAVG, however, in contrast to the latter it is based on re-labeled MCMC traces. This is especially important in case of random permutation during MCMC sampling as component parameters then have to be re-assigned to their (probably) correct component.
For a more detailed outlay of point estimators from Bayesian mixture model estimation, see Fr\"uhwirth-Schnatter (2006).
1 2 3 4 5 6 7 | mcmcestimate(
mcmcout,
method = "kmeans",
fdata = NULL,
permOut = FALSE,
opt_ctrl = list(max_iter = 200L)
)
|
mcmcout |
An |
method |
A character defining the re-labeling method in case of a model with unknown indicators. For most distributions there exists only a single choice, namely "kmeans". For Poisson and Binomial distributions the re-labeling algorithms "Stephens1997a" and "Stephens1997b" can be chosen. |
fdata |
An |
permOut |
A logical indicating, if the permuted MCMC samples should be returned as well. Optional. |
opt_ctrl |
A list with an element |
An mcmcest object containing the point estimates together with
additional information about the underlying finite mixture model, MCMC
sampling hyper-parameters and the data. In case permOut is set to
TRUE, the output of this function is a named list with an mcmcest
object containing parameter estimates and in addition an mcmcoutputperm
object containing the permuted (re-labeled) MCMC samples.
mcmcestfix for object storing the parameter estimates in case of fixed indicators
mcmcestind for object storing the parameter estimates in case of unknown indicators
mcmcoutputperm for classes storing re-labeled MCMC samples
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.