Description Usage Arguments Value See Also
This function calculates the moments for re-labeled MCMC samples of multivariate mixture models. Moments like means, standard deviations, kurtosis and skewness are computed for each iteration in MCMC sampling. The moments are used when plotting the traces of an MCMC sample output.
1 | permmoments_cc(classS4)
|
classS4 |
An |
A named list with vectors containing the data moments for each iteration in the re-labeled MCMC sample.
mcmcoutputperm for the mcmcoutput class definition
mixturemcmc() for performing MCMC sampling
mcmcpermute() for re-labeling MCMC samples
plotTraces() for the calling function
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.