Description Usage Arguments See Also Examples
plot() plots the data in an fdata object by either a histogram in case of
continuous data or a barplot in case of discrete data.
1 2 |
x |
An |
y |
Unused. |
dev |
A logical indicating if the plot should be output via a graphical device. |
... |
Further arguments passed to the plotting functions |
fdata class
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.