Description Usage Arguments Value See Also Examples
plotPointProc plots the point process of an S4 model object that
defines a finite mixture model. Only available for Poisson mixtures so far.
1 2 | ## S4 method for signature 'model'
plotPointProc(x, dev = TRUE, ...)
|
x |
An S4 model object with defined parameters and weights. |
dev |
A logical indicating, if the plot should be shown in a graphical
device. Set to |
... |
Arguments to be passed to methods, such as graphical parameters (see par). |
A scatter plot of weighted parameters.
1 2 3 4 | ## Not run:
plotPointProc(f_model)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.