Description Usage Arguments Value See Also Examples
Sets the slot S of an fdata object and validates the slot data before
setting.
1 2 | ## S4 replacement method for signature 'fdata'
setS(object) <- value
|
object |
An |
value |
A matrix that should be set as |
The fdata object with slot S set to value or an error message
if the value cannot be set as slot S.
fdata for all slots of the fdata class
1 2 3 | # Generate an empty fdata object.
f_data <- fdata()
setS(f_data) <- matrix(sample.int(4, 100, replace = TRUE))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.