Description Usage Arguments Value See Also
This function is used to swap the elements in slot ST of an mcmcoutput
object (An MCMC sampling output). The main difference to the
swapInteger_cc() function is that this function reuses memory from R. Do
only use this function, if you really know what you are doing.
1 | swapST_cc(values, index)
|
values |
An integer matrix containing the values to swap in R memory. |
index |
An integer matrix containing the swapping scheme. |
An integer matrix with swapped values.
swapInteger_cc() for the equivalent function not using R memory
swap_3d_cc() for an equivalent function for three-dimensional arrays
swapElements() for the calling method
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.